@@ -1,4 +1,5 @@
 # Basic
+import json
 import numpy as np
 import argparse
 import pandas as pd
@@ -31,6 +32,7 @@ from sklearn.linear_model import LinearRegression, LogisticRegression
 from sklearn.model_selection import train_test_split
 from sklearn.neural_network import MLPClassifier
 
+from PIL import Image
 
 # Tensorflow
 import tensorflow as tf
@@ -38,8 +40,8 @@ import tensorflow as tf
 
 def main(params):
     # pytorch_titanic()
-    pytorch_cifar()
-    # pytorch_imagenet()
+    # pytorch_cifar()
+    pytorch_imagenet()
     # scikit()
     # tensorflow()
     # tensorflow_titanic()
@@ -101,8 +103,8 @@ def pytorch_cifar():
     criterion = nn.CrossEntropyLoss()
     example = 9  # 9 car, 11 truck
     print(y_test[example])
-    # robustness.fast_gradient_sign_method(num_classes=10, criterion=criterion, visualize=True, eps=0.05,
-    #                                      example=example, classes=classes)
+    robustness.fast_gradient_sign_method(num_classes=10, criterion=criterion, visualize=True, eps=0.05,
+                                         example=example, classes=classes)
     analysis = ComprehensibilityAnalysis(interface)
     analysis.integrated_gradients(img_index=9)
     analysis.grad_cam(model.conv2, img_index=example)
@@ -120,10 +122,28 @@ def pytorch_cifar():
 
 
 def pytorch_imagenet():
+    image = Image.open('data/imagenet_dogs/ILSVRC2012_val_00023440.JPEG')
+
+    with open('data/imagenet_class_index.json') as json_file:
+        class_labels = json.load(json_file)
+
+    class_labels = [class_labels[i][1] for i in class_labels]
     alexnet = models.alexnet(pretrained=True)
-    # normalize = T.Normalize(mean=[0.485, 0.456, 0.406], std=[0.229, 0.224, 0.225])
-    # transform = T.Compose([T.Resize(256), T.CenterCrop(224), T.ToTensor()])
-    # dataset = datasets.ImageNet(".", split="train", transform=transform)
+    alexnet.eval()
+
+    transform = T.Compose([T.Resize(256), T.CenterCrop(224), T.ToTensor(),
+                           T.Normalize(mean=[0.485, 0.456, 0.406], std=[0.229, 0.224, 0.225])])
+    x_test = transform(image)
+    x_test = x_test.unsqueeze(0)
+    y_test = torch.tensor(217).unsqueeze(0)
+
+    interface = PyTorchInterface(alexnet, x_test, y_test, metric_name='accuracy')
+    comprehensibility = ComprehensibilityAnalysis(interface)
+    # print(alexnet.features[10])
+    comprehensibility.integrated_gradients(0)
+    comprehensibility.grad_cam(alexnet.features[10], 0, class_labels=class_labels)
+
+
 
 
 def scikit():
